#!/usr/bin/env python3

from mo.tokens import sign_token, verify_token
import unittest
import mo.config as config


class TestTokens(unittest.TestCase):

    def test_sign(self):
        self.assertEqual(sign_token(['deadbeef', 'číže:k'], 'use'), 'deadbeef:%C4%8D%C3%AD%C5%BEe%3Ak:1397ee86ae5b05d4')

    def test_verify(self):
        self.assertEqual(verify_token('deadbeef:%C4%8D%C3%AD%C5%BEe%3Ak:1397ee86ae5b05d4', 'use'), ['deadbeef', 'číže:k'])

    def test_bad_use(self):
        self.assertEqual(verify_token('deadbeef:%C4%8D%C3%AD%C5%BEe%3Ak:1397ee86ae5b05d4', 'misuse'), None)

    def test_bad_sign(self):
        self.assertEqual(verify_token('deadbeef:%C4%8D%C3%AD%C5%BEe%3Ak:1397', 'use'), None)

    def test_truncated(self):
        self.assertEqual(verify_token('deadbeef', 'use'), None)

    def test_empty_sig(self):
        self.assertEqual(verify_token('deadbeef:%C4%8D%C3%AD%C5%BEe%3Ak:', 'use'), None)


if __name__ == '__main__':
    config.SECRET_KEY = 'XYZZY'
    unittest.main()
