# Podepsané tokeny

import hmac
import urllib.parse
from typing import Optional, List

import mo.config as config


def _sign_token(token: str, use: str) -> str:
    key = '-'.join(('sign-token', use, config.SECRET_KEY))
    mac = hmac.HMAC(key.encode('us-ascii'), token.encode('us-ascii'), 'sha256')
    return mac.hexdigest()[:16]


def sign_token(fields: List[str], use: str) -> str:
    enc_fields = [urllib.parse.quote(f) for f in fields]
    t = ':'.join(enc_fields)
    return t + ':' + _sign_token(t, use)


def verify_token(token: str, use: str) -> Optional[List[str]]:
    enc_fields = token.split(':')
    if len(enc_fields) < 2:
        return None
    sign = enc_fields.pop()
    if _sign_token(':'.join(enc_fields), use) != sign:
        return None
    return [urllib.parse.unquote(f) for f in enc_fields]
