from flask import render_template, redirect, url_for, request, flash
from sqlalchemy.orm import aliased

import mo.db as db
from mo.web.jinja import user_url
import mo.users
from mo.web.table import Table, Row, Column
from mo.web import app


@app.route('/org/')
def org_index():
    if 'place' in request.args:
        code = request.args['place']
        place = db.get_place_by_code(code)
        if place is not None:
            return redirect(url_for('org_place', id=place.place_id))
        else:
            flash(f'Místo s kódem {code} neexistuje', 'danger')

    if 'uid' in request.args:
        try:
            uid = int(request.args['uid'])
            user = mo.users.user_by_uid(uid)
            if user is not None:
                return redirect(user_url(user))
            flash(f'Uživatel s ID {uid} neexistuje', 'danger')
        except ValueError:
            flash('ID uživatele musí být číslo', 'danger')

    return render_template('org_index.html')


school_export_columns = (
    Column(key='code', name='kod'),
    Column(key='name', name='nazev'),
    Column(key='town_code', name='kod_obce'),
    Column(key='town', name='obec'),
    Column(key='red_izo', name='red_izo'),
    Column(key='ico', name='ico'),
    Column(key='official_name', name='ofic_nazev'),
    Column(key='address', name='adresa'),
    Column(key='is_zs', name='typ_zs'),
    Column(key='is_ss', name='typ_ss'),
)


@app.route('/org/export/skoly')
def org_export_skoly():
    sess = db.get_session()
    format = request.args.get('format', 'en_csv')

    def gen_rows():
        town = aliased(db.Place)
        for p, s, t in (
                sess.query(db.Place, db.School, town)
                .filter(db.Place.type == db.PlaceType.school)
                .filter(db.Place.place_id == db.School.place_id)
                .filter(db.Place.parent == town.place_id)
                .yield_per(100)):
            yield Row(keys={
                'code': p.get_code(),
                'name': p.name,
                'red_izo': s.red_izo,
                'ico': s.ico,
                'official_name': s.official_name,
                'address': s.address,
                'is_zs': int(s.is_zs),
                'is_ss': int(s.is_ss),
                'town_code': t.get_code(),
                'town': t.name,
            })

    table = Table(school_export_columns, gen_rows(), 'skoly')
    return table.send_as(format, streaming=True)
