class NewsReloader {
	news_count = 0;
	notification_interval = null;
	original_title = "";

	constructor(element, status_element, url, check_interval=60000) {
		this.element = element;
		this.status_element = status_element;
		this.url = url;
		this.check_interval = check_interval;

		this.news_count = element.childElementCount;
		this.original_title = document.title;

		var t = this
		setInterval(function() { t.refreshNews();}, this.check_interval);
		window.addEventListener('focus', function() {
			t.news_count = t.element.childElementCount;
			t.notificationOff();
		});
	}

	notificationOn(notification) {
		clearInterval(this.notification_interval); // clear any previous interval
		var t = this;
		this.notification_interval = setInterval(function() {
			document.title = (t.original_title == document.title)
					? notification + t.original_title
					: t.original_title;
		}, 1000);
	}

	notificationOff() {
		if (this.notification_interval) {
			clearInterval(this.notification_interval);
			document.title = this.original_title;
		}
	}

	refreshNews() {
		var xmlhttp = new XMLHttpRequest();
		var t = this;
		xmlhttp.onreadystatechange = function() {
			if (this.readyState == 4 && this.status == 200) {
				var newsArr = JSON.parse(this.responseText);
				var count = newsArr.length

				if (t.status_element != null) {
					if (count == 0) {
						t.status_element.innerHTML = "<p><em>Žádné novinky zatím nebyly vydány.</em>";
					} else {
						t.status_element.innerHTML = "";
					}
				}

				var markN = 0; // how many elements to mark with class "new"
				if (count > t.news_count) {
					markN = count - t.news_count;
				}

				// Create all new <div>s
				var newElements = document.createDocumentFragment();
				for (var i = 0; i < count; i++) {
					var div = document.createElement("div");
					div.className = "message";
					if (i + markN >= count) div.className += " new"; // mark N last elements
					div.innerHTML = "<span class='msg-title'>" + newsArr[i]["title"] + "</span>"
							+"<span class='msg-date'>" + newsArr[i]["date_format"] + "</span>"
							+"<div class='msg-text'>" + newsArr[i]["body"] + "</div>";
					newElements.appendChild(div);
				}

				// Remove all childs and append new
				t.element.innerHTML = "";
				t.element.appendChild(newElements);

				// Notification
				if (count != t.news_count) {
					if (document.hasFocus()) t.news_count = count;
					else {
						// Add (1) to the title (with removing any previous value)
						t.notificationOn("(" + Math.abs(count - t.news_count).toString() + ") ");
					}
				}
			}
		}
		xmlhttp.open("GET", this.url, true);
		xmlhttp.send();
	}
}
